@@ -670,7 +670,6 @@ enum btree_write_type {
 	x(fake)								\
 	x(need_rewrite)							\
 	x(need_rewrite_error)						\
-	x(need_rewrite_degraded)					\
 	x(need_rewrite_ptr_written_zero)				\
 	x(never_write)							\
 	x(pinned)
@@ -700,7 +699,6 @@ BTREE_FLAGS()
 	x(none)								\
 	x(unknown)							\
 	x(error)							\
-	x(degraded)							\
 	x(ptr_written_zero)
 
 enum btree_node_rewrite_reason {
@@ -744,8 +742,6 @@ static inline enum btree_node_rewrite_reason btree_node_rewrite_reason(struct bt
 {
 	if (btree_node_need_rewrite_ptr_written_zero(b))
 		return BTREE_NODE_REWRITE_ptr_written_zero;
-	if (btree_node_need_rewrite_degraded(b))
-		return BTREE_NODE_REWRITE_degraded;
 	if (btree_node_need_rewrite_error(b))
 		return BTREE_NODE_REWRITE_error;
 	if (btree_node_need_rewrite(b))
