@@ -20,7 +20,14 @@
 #include <linux/kthread.h>
 #include <linux/sched/mm.h>
 
-static bool __should_discard_bucket(struct journal *, struct journal_device *);
+static bool __should_discard_bucket(struct journal *j, struct journal_device *ja)
+{
+	unsigned min_free = max(4, ja->nr / 2);
+
+	return bch2_journal_dev_buckets_available(j, ja, journal_space_discarded) <
+		min_free &&
+		ja->discard_idx != ja->dirty_idx_ondisk;
+}
 
 /* Free space calculations: */
 
@@ -223,20 +230,23 @@ void bch2_journal_space_available(struct journal *j)
 		       ja->bucket_seq[ja->dirty_idx_ondisk] < j->last_seq_ondisk)
 			ja->dirty_idx_ondisk = (ja->dirty_idx_ondisk + 1) % ja->nr;
 
-		can_discard |= __should_discard_bucket(j, ja);
-
 		max_entry_size = min_t(unsigned, max_entry_size, ca->mi.bucket_size);
 		nr_online++;
+
+		can_discard |= __should_discard_bucket(j, ja);
+
+		if (__should_discard_bucket(j, ja) &&
+		    test_bit(BCH_FS_rw_init_done, &c->flags))
+			queue_work(j->discard_wq, &ja->discard);
 	}
 
 	j->can_discard = can_discard;
 
-	if (nr_online < metadata_replicas_required(c)) {
+	if (!nr_online) {
 		if (!(c->sb.features & BIT_ULL(BCH_FEATURE_small_image))) {
 			CLASS(printbuf, buf)();
 			guard(printbuf_atomic)(&buf);
-			prt_printf(&buf, "insufficient writeable journal devices available: have %u, need %u\n"
-				   "rw journal devs:", nr_online, metadata_replicas_required(c));
+			prt_printf(&buf, "no writeable journal devices available\n");
 
 			for_each_member_device_rcu(c, ca, &c->allocator.rw_devs[BCH_DATA_journal])
 				prt_printf(&buf, " %s", ca->name);
@@ -279,49 +289,59 @@ void bch2_journal_space_available(struct journal *j)
 
 /* Discards - last part of journal reclaim: */
 
-static bool __should_discard_bucket(struct journal *j, struct journal_device *ja)
-{
-	unsigned min_free = max(4, ja->nr / 8);
-
-	return bch2_journal_dev_buckets_available(j, ja, journal_space_discarded) <
-		min_free &&
-		ja->discard_idx != ja->dirty_idx_ondisk;
-}
-
 static bool should_discard_bucket(struct journal *j, struct journal_device *ja)
 {
 	guard(spinlock)(&j->lock);
 	return __should_discard_bucket(j, ja);
 }
 
+static void bch2_journal_dev_do_discards(struct journal_device *ja)
+{
+	struct bch_dev *ca = container_of(ja, struct bch_dev, journal);
+	struct bch_fs *c = ca->fs;
+	struct journal *j = &c->journal;
+
+	if (!bch2_dev_get_ioref(c, ca->dev_idx, WRITE, BCH_DEV_WRITE_REF_journal_discard))
+		return;
+
+	guard(mutex)(&ja->discard_lock);
+
+	while (should_discard_bucket(j, ja)) {
+		if (!c->opts.nochanges &&
+		    bch2_discard_opt_enabled(c, ca) &&
+		    bdev_max_discard_sectors(ca->disk_sb.bdev))
+			blkdev_issue_discard(ca->disk_sb.bdev,
+					     bucket_to_sector(ca,
+							      ja->buckets[ja->discard_idx]),
+					     ca->mi.bucket_size, GFP_NOFS);
+
+		scoped_guard(spinlock, &j->lock) {
+			ja->discard_idx = (ja->discard_idx + 1) % ja->nr;
+			bch2_journal_space_available(j);
+		}
+	}
+
+	enumerated_ref_put(&ca->io_ref[WRITE],
+			   BCH_DEV_WRITE_REF_journal_discard);
+}
+
 /*
  * Advance ja->discard_idx as long as it points to buckets that are no longer
  * dirty, issuing discards if necessary:
  */
+void bch2_journal_discard_work(struct work_struct *work)
+{
+	struct journal_device *ja = container_of(work, struct journal_device, discard);
+
+	bch2_journal_dev_do_discards(ja);
+}
+
 void bch2_journal_do_discards(struct journal *j)
 {
 	struct bch_fs *c = container_of(j, struct bch_fs, journal);
 
-	guard(mutex)(&j->discard_lock);
-
-	for_each_rw_member(c, ca, BCH_DEV_WRITE_REF_journal_do_discards) {
-		struct journal_device *ja = &ca->journal;
-
-		while (should_discard_bucket(j, ja)) {
-			if (!c->opts.nochanges &&
-			    bch2_discard_opt_enabled(c, ca) &&
-			    bdev_max_discard_sectors(ca->disk_sb.bdev))
-				blkdev_issue_discard(ca->disk_sb.bdev,
-					bucket_to_sector(ca,
-						ja->buckets[ja->discard_idx]),
-					ca->mi.bucket_size, GFP_NOFS);
-
-			scoped_guard(spinlock, &j->lock) {
-				ja->discard_idx = (ja->discard_idx + 1) % ja->nr;
-				bch2_journal_space_available(j);
-			}
-		}
-	}
+	for_each_member_device(c, ca)
+		bch2_journal_dev_do_discards(&ca->journal);
 }
 
 /*
@@ -733,9 +753,6 @@ static int __bch2_journal_reclaim(struct journal *j, bool direct, bool kicked)
 		if (ret)
 			break;
 
-		/* XXX shove journal discards off to another thread */
-		bch2_journal_do_discards(j);
-
 		seq_to_flush = journal_seq_to_flush(j);
 		min_nr = 0;
 
